| Tool (**Package**) | Citation(s) | Link to code or documentation |
|-----|-----|-----|
| **FreeSurfer** | | https://github.com/freesurfer/freesurfer |
| recon-all | https://doi.org/10.1006/nimg.1998.0395 | https://surfer.nmr.mgh.harvard.edu/fswiki/recon-all |
| bbregister & BBR | https://doi.org/10.1016/j.neuroimage.2009.06.060 |  |
| mri_robust_template | https://doi.org/10.1016/j.neuroimage.2012.02.084 | https://surfer.nmr.mgh.harvard.edu/fswiki/mri_robust_template |
| mri_robust_register | https://doi.org/10.1016/j.neuroimage.2010.07.020 | https://surfer.nmr.mgh.harvard.edu/fswiki/mri_robust_register |
| mris_expand | | https://mail.nmr.mgh.harvard.edu/pipermail/freesurfer/2009-July/011152.html |
| **ANTs** | https://doi.org/10.3389/fninf.2015.00005 | https://github.com/ANTsX/ANTs |
| antsRegistration | https://doi.org/10.1016/j.media.2007.06.004 https://doi.org/10.1016/j.neuroimage.2010.09.025 | |
| N4BiasFieldCorrection | https://doi.org/10.1109/TMI.2010.2046908 | |
| antsBrainExtraction.sh | https://doi.org/10.1038/sdata.2015.3 | https://github.com/ANTsX/ANTs/blob/v2.2.0/Scripts/antsBrainExtraction.sh |
| **FSL** | | https://doi.org/10.1016/j.neuroimage.2004.07.051 https://doi.org/10.1016/j.neuroimage.2008.10.055 https://doi.org/10.1016/j.neuroimage.2011.09.015
| FAST | https://doi.org/10.1109/42.906424 | https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FAST |
| BET | https://doi.org/10.1002/hbm.10062 | https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/BET |
| FLIRT | https://doi.org/10.1006/nimg.2002.1132 https://doi.org/10.1016/S1361-8415(01)00036-6 | https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FLIRT; https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FLIRT_BBR |
| MCFLIRT | https://doi.org/10.1006/nimg.2002.1132 | https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/MCFLIRT |
| SUSAN | https://doi.org/10.1023/A:1007963824710 | https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/SUSAN |
| MELODIC | | https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/MELODIC |
| PRELUDE & FUGUE | https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FUGUE/Guide | https://nipype.readthedocs.io/en/latest/interfaces/generated/workflows.dmri/fsl.utils.html#cleanup-edge-pipeline |
| **AFNI** | | https://doi.org/10.1006/cbmr.1996.0014; https://doi.org/10.1016/j.neuroimage.2011.08.056
| 3dvolreg | | https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dvolreg.html |
| 3dTshift | | https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dTshift.html |
| 3dUnifize | | https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dUnifize.html |
| 3dAutomask | | https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dAutomask.html |
| **Power, et al. (2012) measures** | https://doi.org/10.1016/j.neuroimage.2011.10.018 | |
| DVARS | https://arxiv.org/abs/1704.01469 https://doi.org/10.1101/125021 | https://nipype.readthedocs.io/en/latest/interfaces/generated/nipype.algorithms.confounds.html#computedvars |
| Framewise displacement | | https://nipype.readthedocs.io/en/latest/interfaces/generated/nipype.algorithms.confounds.html#framewisedisplacement |
| **Other**
| a/tCompCor | https://doi.org/10.1016/j.neuroimage.2007.04.042 | https://nipype.readthedocs.io/en/latest/api/generated/nipype.algorithms.confounds.html#nipype-algorithms-confounds-compcor |
| Connectome Workbench | | https://humanconnectome.org/software/connectome-workbench
| phdiff2fmap | https://doi.org/10.1006/nimg.2001.1054 | https://fmriprep.readthedocs.io/en/stable/sdc/estimation.html#fmriprep.interfaces.fmap.phdiff2fmap |
| nibabel | https://doi.org/10.5281/zenodo.60808 | https://github.com/nipy/nibabel/ |
| nilearn | https://doi.org/10.3389/fninf.2014.00014 | https://github.com/nilearn/nilearn/ |
| nipype | https://doi.org/10.3389/fninf.2011.00013 https://doi.org/10.5281/zenodo.581704 | https://github.com/nipy/nipype/ |
| **Graphics**
| seaborn | https://doi.org/10.5281/zenodo.883859 | https://github.com/mwaskom/seaborn |
| matplotlib 2.0.0 | https://doi.org/10.5281/zenodo.248351 | https://github.com/matplotlib/matplotlib |
| cwebp | https://developers.google.com/speed/webp/docs/webp_study https://developers.google.com/speed/webp/docs/webp_lossless_alpha_study | https://developers.google.com/speed/webp/ |
| SVGO | | https://github.com/svg/svgo |
